@@ -13,15 +13,15 @@ class ModifyInstanceAttributesAction(BaseAction):
 
         parser.add_argument('-i', '--instance_id', dest='instance_id',
                 action='store', type=str, default='',
-                help='The id of the instance whose attributes you want to modify.')
+                help='the id of the instance whose attributes you want to modify.')
 
         parser.add_argument('-N', '--instance_name', dest='instance_name',
                 action='store', type=str, default='',
-                help='Instance name')
+                help='instance name')
 
         parser.add_argument('-D', '--description', dest='description',
                 action='store', type=str, default='',
-                help='Instance description')
+                help='instance description')
 
         return parser
 
