@@ -12,7 +12,7 @@ class ModifyRouterAttributesAction(BaseAction):
     def add_ext_arguments(cls, parser):
         parser.add_argument('-r', '--router', dest='router',
                 action='store', type=str, default='',
-                help='The id of the router whose attributes you want to modify.')
+                help='the id of the router whose attributes you want to modify.')
      
         parser.add_argument('-e', '--eip', dest='eip',
                 action='store', type=str, default='',
@@ -20,15 +20,15 @@ class ModifyRouterAttributesAction(BaseAction):
      
         parser.add_argument('-s', '--security_group', dest='security_group',
                 action='store', type=str, default='',
-                help='The id of the security_group you want to apply to router.')
+                help='the id of the security_group you want to apply to router.')
 
         parser.add_argument('-N', '--router_name', dest='router_name',
                 action='store', type=str, default='',
-                help='New router_name.')
+                help='new router_name.')
 
         parser.add_argument('-D', '--description', dest='description',
                 action='store', type=str, default='',
-                help='New description.')
+                help='new description.')
               
     @classmethod
     def build_directive(cls, options):
