@@ -13,17 +13,17 @@ class LeaveVxnetAction(BaseAction):
     def add_ext_arguments(cls, parser):
         parser.add_argument('-i', '--instances', dest='instances',
                 action='store', type=str, default='',
-                help='The IDs of instances that will leave a vxnet.')
+                help='the IDs of instances that will leave a vxnet.')
 
         parser.add_argument('-v', '--vxnet', dest='vxnet',
                 action='store', type=str, default='',
-                help='The id of the vxnet the instances will leave. ')
+                help='the ID of the vxnet the instances will leave. ')
       
     @classmethod
     def build_directive(cls, options):
         instances = explode_array(options.instances)
         if not options.vxnet or not instances:
-            print 'instances and vxnet should be specified'
+            print 'error: [instances] and [vxnet] should be specified'
             return None
 
         return {
