@@ -774,16 +774,19 @@ class APIConnection(HttpConnection):
     def modify_security_group_rule_attributes(self,
                                               security_group_rule,
                                               priority,
+                                              security_group_rule_name=None,
                                               **params):
         """
             @param security_group_rule: the ID of the security group rule whose attributes you
                                       want to update.
             @param priority: priority [0 - 100].
+            @param security_group_rule_name: name of the rule.
         """
         action = ACTION_MODIFY_SECURITY_GROUP_RULE_ATTRIBUTES
         body = {}
         body['security_group_rule'] = security_group_rule
         body['priority'] = priority
+        body['security_group_rule_name'] = security_group_rule_name
 
         return self.send_request(action, body)
 
@@ -1229,6 +1232,7 @@ class APIConnection(HttpConnection):
                       status = None,
                       eip_group = None,
                       eip_name = None,
+                      instance_id = None,
                       search_word = None,
                       offset = None,
                       limit = None,
@@ -1238,6 +1242,7 @@ class APIConnection(HttpConnection):
             @param status: filter eips by status
             @param eip_group: filter eips by eip group.
             @param eip_name: the name of the eip. Support partial match.
+            @param instance_id: filter eips by instance.
             @param search_word: search word column.
             @param offset: the starting offset of the returning results.
             @param limit: specify the number of the returning results.
@@ -1253,6 +1258,8 @@ class APIConnection(HttpConnection):
             body['eip_group'] = eip_group
         if eip_name:
             body['eip_name'] = eip_name
+        if instance_id:
+            body['instance_id'] = instance_id
         if search_word:
             body['search_word'] = search_word
         if offset:
